Documentation
¶
Overview ¶
package appmanifest provides utilities for managing app manifest files used by MDM InstallApplication commands.
Index ¶
Constants ¶
const DefaultMD5Size = 10 << 20 // 10MB
DefaultMD5Size is the default size of each file chunk that needs to be hashed
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BundleInfo ¶
type Metadata ¶
type Metadata struct {
BundleInfo
Items []BundleInfo `plist:"items,omitempty"`
Kind string `plist:"kind"`
Subtitle string `plist:"subtitle"`
Title string `plist:"title"`
}
Click to show internal directories.
Click to hide internal directories.