Documentation
¶
Index ¶
- Constants
- func MakeApplyBlueprintEndpoint(svc Service) endpoint.Endpoint
- func MakeGetBlueprintsEndpoint(svc Service) endpoint.Endpoint
- func MakeRemoveBlueprintsEndpoint(svc Service) endpoint.Endpoint
- func MarshalBlueprint(bp *Blueprint) ([]byte, error)
- func RegisterHTTPHandlers(r *mux.Router, e Endpoints, options ...httptransport.ServerOption)
- func UnmarshalBlueprint(data []byte, bp *Blueprint) error
- type Blueprint
- type BlueprintService
- type BlueprintWorkerStore
- type Endpoints
- type GetBlueprintsOption
- type ProfileStore
- type Service
- type Store
- type UserStore
- type Worker
Constants ¶
const (
ApplyAtEnroll string = "Enroll"
)
ApplyAt is a case-insensitive string that specifies at which point the system should apply a Blueprint to devices. For example if a Blueprint has an ApplyAt of "Enroll" then that profile will be applied immediately after a device's enrollment in the MDM system. Currently "Enroll" is the only supported value but more are planned.
Variables ¶
This section is empty.
Functions ¶
func MarshalBlueprint ¶
func RegisterHTTPHandlers ¶
func RegisterHTTPHandlers(r *mux.Router, e Endpoints, options ...httptransport.ServerOption)
func UnmarshalBlueprint ¶
Types ¶
type Blueprint ¶
type Blueprint struct {
UUID string `json:"uuid"`
Name string `json:"name"`
ApplicationURLs []string `json:"install_application_manifest_urls"`
ProfileIdentifiers []string `json:"profile_ids"`
UserUUID []string `json:"user_uuids"`
SkipPrimarySetupAccountCreation bool `json:"skip_primary_setup_account_creation"`
SetPrimarySetupAccountAsRegularUser bool `json:"set_primary_setup_account_as_regular_user"`
ApplyAt []string `json:"apply_at"`
}
type BlueprintService ¶
type BlueprintService struct {
// contains filtered or unexported fields
}
func New ¶
func New(store Store) *BlueprintService
func (*BlueprintService) ApplyBlueprint ¶
func (svc *BlueprintService) ApplyBlueprint(ctx context.Context, bp *Blueprint) error
func (*BlueprintService) GetBlueprints ¶
func (svc *BlueprintService) GetBlueprints(ctx context.Context, opt GetBlueprintsOption) ([]Blueprint, error)
func (*BlueprintService) RemoveBlueprints ¶
func (svc *BlueprintService) RemoveBlueprints(ctx context.Context, names []string) error
type BlueprintWorkerStore ¶ added in v1.5.0
type Endpoints ¶
type Endpoints struct {
ApplyBlueprintEndpoint endpoint.Endpoint
GetBlueprintsEndpoint endpoint.Endpoint
RemoveBlueprintsEndpoint endpoint.Endpoint
}
func MakeServerEndpoints ¶
func MakeServerEndpoints(s Service, outer endpoint.Middleware, others ...endpoint.Middleware) Endpoints
func (Endpoints) ApplyBlueprint ¶
func (Endpoints) GetBlueprints ¶
type GetBlueprintsOption ¶
type GetBlueprintsOption struct {
FilterName string
}
type ProfileStore ¶ added in v1.5.0
type Service ¶
type Service interface {
ApplyBlueprint(ctx context.Context, bp *Blueprint) error
GetBlueprints(ctx context.Context, opt GetBlueprintsOption) ([]Blueprint, error)
RemoveBlueprints(ctx context.Context, names []string) error
}
func NewHTTPClient ¶
func NewHTTPClient(instance, token string, logger log.Logger, opts ...httptransport.ClientOption) (Service, error)
type Worker ¶ added in v1.5.0
type Worker struct {
// contains filtered or unexported fields
}
func NewWorker ¶ added in v1.5.0
func NewWorker( db BlueprintWorkerStore, userDB UserStore, profileDB ProfileStore, cmdsvc command.Service, sub pubsub.Subscriber, logger log.Logger, ) *Worker
Source Files
¶
Click to show internal directories.
Click to hide internal directories.